from functools import lru_cache
import logging

from sync_amz_data.public import BaseClient
from sync_amz_data.settings import AWS_LWA_CLIENT, DATA_PATH

logger = logging.getLogger(__name__)


@lru_cache(maxsize=100)
def query_shop_info(profile_id: str) -> dict:
    return {}


class BaseTask:
    AmzAdClientClass = BaseClient

    def __init__(self, profile_id: str):
        self.shop_info = query_shop_info(profile_id)
        self.ad_cil = self.AmzAdClientClass(
            profile_id=profile_id,
            refresh_token=self.shop_info["refresh_token"],
            data_path=DATA_PATH, **AWS_LWA_CLIENT)

    def do(self, task_info: dict):
        record = task_info["record"]
        iter_records = getattr(self.ad_cil, f"iter_{record}")
        change_func = getattr(self, f"change_{record}", None)
        for data in iter_records(task_info["params"]):
            if change_func:
                data = change_func(self, data)
            self.to_mysql(record, data)
            logger.info(data)

    def to_mysql(self, record: str, data: dict):
        pass
